@@ -27,9 +27,8 @@ class Histogram(Vis):
 
     def __init__(self, df: pd.DataFrame, x: object, title='', xlabel='', ylabel='', colour=None, normalise=False, fit_norm=False,
                  plot_rug=False, plot_kde=False, plot_hist=True, bins=20, min_x=None, max_x=None, min_y=None, max_y=None,
-                 figsize=(3, 3), title_font_size=12, label_font_size=8, title_font_weight=700, config={}):
-        super().__init__(df, figsize=figsize, title_font_size=title_font_size, label_font_size=label_font_size,
-                         title_font_weight=title_font_weight)
+                 figsize=(3, 3), config={}):
+        super().__init__(df, figsize=figsize)
         self.df = df
         self.x = x
         self.title = title
@@ -50,7 +49,7 @@ class Histogram(Vis):
         if config:
             self.load_style(config)
 
-    def plot(self):
+    def plot(self, ax=None):
         x = self.x
         # First lets check whether we were passed lists or strings for our y and x arrays
         if not isinstance(x, str):
@@ -65,8 +64,11 @@ class Histogram(Vis):
             ax = sns.distplot(values, fit=norm, kde=self.plot_kde, rug=self.plot_rug, hist=self.plot_hist,
                               norm_hist=self.normalise, bins=self.bins)
         else:
-            ax = sns.distplot(values, kde=self.plot_kde, rug=self.plot_rug, hist=self.plot_hist,
-                              norm_hist=self.normalise, bins=self.bins, color=self.colour)
+            if ax is not None:
+                ax = ax.hist(values, bins=self.bins, color=self.colour)
+            else:
+                ax = sns.distplot(values, fit=norm, kde=self.plot_kde, rug=self.plot_rug, hist=self.plot_hist,
+                                  bins=self.bins)
         self.add_labels()
         self.apply_limits('x', self.max_x, self.min_x)
         self.apply_limits('y', self.max_y, self.min_y)
